==> pomp_4.5.tar.gz: pomp/man/macros/citations.Rd <==
% unlike in latex, new lines within \newcommand end the command (even using %)

\newcommand{\Anderson2001}{J.L. Anderson. An ensemble adjustment Kalman filter for data assimilation. \emph{Monthly Weather Review} \bold{129}, 2884--2903, 2001.}

\newcommand{\Andrieu2009}{C. Andrieu and G.O. Roberts. The pseudo-marginal approach for computation. \emph{Annals of Statistics} \bold{37}, 697--725, 2009.}

\newcommand{\Andrieu2010}{C. Andrieu, A. Doucet, and R. Holenstein. Particle Markov chain Monte Carlo methods. \emph{Journal of the Royal Statistical Society, Series B} \bold{72}, 269--342, 2010.}

\newcommand{\Anonymous1978}{Anonymous. Influenza in a boarding school. \emph{British Medical Journal} \bold{1}, 587, 1978.}

\newcommand{\Arulampalam2002}{M.S. Arulampalam, S. Maskell, N. Gordon, & T. Clapp. A tutorial on particle filters for online nonlinear, non-Gaussian Bayesian tracking. \emph{IEEE Transactions on Signal Processing} \bold{50}, 174--188, 2002.}

\newcommand{\Bhadra2016}{A. Bhadra and E.L. Ionides. Adaptive particle allocation in iterated sequential Monte Carlo via approximating meta-models. \emph{Statistics and Computing} \bold{26}, 393--407, 2016.}

\newcommand{\Bratley1988}{P. Bratley and B.L. Fox. Algorithm 659 Implementing Sobol's quasirandom sequence generator. \emph{ACM Transactions on Mathematical Software} \bold{14}, 88--100, 1988.}

\newcommand{\Breto2011}{C. \ifelse{latex}{\out{Bret\'o}}{\ifelse{html}{\out{Breto&oacute;}}{Breto}} and E. L. Ionides. Compound Markov counting processe and their applications to modeling infinitesimally over-dispersed systems. \emph{Stochastic Processes and their Applications} \bold{121}, 2571--2591, 2011.}

\newcommand{\Brillinger1980}{D.R. Brillinger, J. Guckenheimer, P. Guttorp, and G. Oster. Empirical modelling of population time series: The case of age and density dependent rates. In: G. Oster (ed.), \emph{Some Questions in Mathematical Biology} vol. 13, pp. 65--90, American Mathematical Society, Providence, 1980.}

\newcommand{\Ellner1998}{S.P. Ellner, B.A. Bailey, G.V. Bobashev, A.R. Gallant, B.T. Grenfell, and D.W. Nychka. Noise and nonlinearity in measles epidemics: combining mechanistic and statistical approaches to population modeling. \emph{American Naturalist} \bold{151}, 425--440, 1998.}

\newcommand{\Evensen1994}{G. Evensen. Sequential data assimilation with a nonlinear quasi-geostrophic model using Monte Carlo methods to forecast error statistics. \emph{Journal of Geophysical Research: Oceans} \bold{99}, 10143--10162, 1994.}

\newcommand{\Evensen2009}{G. Evensen. \emph{Data assimilation: the ensemble Kalman filter}. Springer-Verlag, 2009.}

\newcommand{\Gurney1980}{W.S.C. Gurney, S.P. Blythe, and R.M. Nisbet. Nicholson's blowflies revisited. \emph{Nature} \bold{287}, 17--21, 1980.}

\newcommand{\He2010}{D. He, E.L. Ionides, & A.A. King. Plug-and-play inference for disease dynamics: measles in large and small populations as a case study.  \emph{Journal of the Royal Society Interface} \bold{7}, 271--283, 2010.}

\newcommand{\Ionides2011}{E.L. Ionides. Discussion of \dQuote{Feature matching in time series modeling} by Y. Xia and H. Tong. \emph{Statistical Science} \bold{26}, 49--52, 2011.}

\newcommand{\Ionides2015}{E.L. Ionides, D. Nguyen, Y. \ifelse{latex}{\out{Atchad\'e}}{\ifelse{html}{\out{Atchad&eacute;}}{Atchade}}, S. Stoev, and A.A. King. Inference for dynamic and latent variable models via iterated, perturbed Bayes maps. \emph{Proceedings of the National Academy of Sciences} \bold{112}, 719--724, 2015.}

\newcommand{\Ionides2017}{E. L. Ionides, C. Breto, J. Park, R. A. Smith, and A. A. King. Monte Carlo profile confidence intervals for dynamic systems. \emph{Journal of the Royal Society, Interface} \bold{14}, 20170126, 2017.}

\newcommand{\Joe2003}{S. Joe and F.Y. Kuo. Remark on algorithm 659: Implementing Sobol' quasirandom sequence generator. \emph{ACM Transactions on Mathematical Software} \bold{29}, 49--57, 2003.}

\newcommand{\Kendall1999}{B.E. Kendall, C.J. Briggs, W.W. Murdoch, P. Turchin, S.P. Ellner, E. McCauley, R.M. Nisbet, and S.N. Wood. Why do populations cycle? A synthesis of statistical and mechanistic modeling approaches. \emph{Ecology} \bold{80}, 1789--1805, 1999.}

\newcommand{\Kendall2005}{B.E. Kendall, S.P. Ellner, E. McCauley, S.N. Wood, C.J. Briggs, W.W. Murdoch, and P. Turchin. Population cycles in the pine looper moth (\emph{Bupalus piniarius}): dynamical tests of mechanistic hypotheses. \emph{Ecological Monographs} \bold{75} 259--276, 2005.}

\newcommand{\King2008}{A.A. King, E.L. Ionides, M. Pascual, and M.J. Bouma. Inapparent infections and cholera dynamics. \emph{Nature} \bold{454}, 877-880, 2008}

\newcommand{\King2015}{A.A. King, M. Domenech de \ifelse{latex}{\out{Cell\`es}}{\ifelse{html}{\out{Cell&egrave;s}}{Celles}}, F.M.G. Magpantay, and P. Rohani. Avoidable errors in the modelling of outbreaks of emerging pathogens, with special reference to Ebola. \emph{Proceedings of the Royal Society of London, Series B} \bold{282}, 20150347, 2015.}

\newcommand{\King2016}{A. A. King, D. Nguyen, and E. L. Ionides. Statistical inference for partially observed Markov processes via the package \pkg{pomp}. \emph{Journal of Statistical Software} \bold{69}(12), 1--43, 2016.  An updated version of this paper is available on the \href{https://kingaa.github.io/pomp/docs.html}{package website}.}

\newcommand{\Kucherenko2005}{S. Kucherenko and Y. Sytsko. Application of deterministic low-discrepancy sequences in global optimization. \emph{Computational Optimization and Applications} \bold{30}, 297--318, 2005. \doi{10.1007/s10589-005-4615-1}.}

\newcommand{\Liu2001}{J. Liu and M. West. Combining Parameter and State Estimation in Simulation-Based Filtering. In A. Doucet, N. de Freitas, and N. J. Gordon, (eds.), \emph{Sequential Monte Carlo Methods in Practice}, pp. 197--224. Springer, New York, 2001.}

\newcommand{\London1973}{W. P. London and J. A. Yorke, Recurrent outbreaks of measles, chickenpox and mumps: I. Seasonal variation in contact rates. \emph{American Journal of Epidemiology} \bold{98}, 453--468, 1973.}

\newcommand{\Marin2012}{J.-M. Marin, P. Pudlo, C. P. Robert, and R. J. Ryder. Approximate Bayesian computational methods. \emph{Statistics and Computing} \bold{22}, 1167--1180, 2012.}

\newcommand{\McCleery1991}{R. McCleery and C. Perrins. Effects of predation on the numbers of Great Tits, \emph{Parus major}. In: C.M. Perrins, J.-D. Lebreton, and G.J.M. Hirons (eds.), \emph{Bird Population Studies}, pp. 129--147, Oxford. Univ. Press, 1991.}

\newcommand{\NLopt}{S.G. Johnson. The \pkg{NLopt} nonlinear-optimization package. \url{https://github.com/stevengj/nlopt/}.}

\newcommand{\Nicholson1957}{A.J. Nicholson. The self-adjustment of populations to change. \emph{Cold Spring Harbor Symposia on Quantitative Biology} \bold{22}, 153--173, 1957.}

\newcommand{\Reuman2006}{D.C. Reuman, R.A. Desharnais, R.F. Costantino, O. Ahmad, J.E. Cohen. Power spectra reveal the influence of stochasticity on nonlinear population dynamics. \emph{Proceedings of the National Academy of Sciences} \bold{103}, 18860-18865, 2006}

\newcommand{\Reuman2008}{D.C. Reuman, R.F. Costantino, R.A. Desharnais, J.E. Cohen. Color of environmental noise affects the nonlinear dynamics of cycling, stage-structured populations. \emph{Ecology Letters} \bold{11}, 820-830, 2008.}

\newcommand{\Roberts2009}{G.O. Roberts and J.S. Rosenthal. Examples of adaptive MCMC. \emph{Journal of Computational and Graphical Statistics} \bold{18}, 349--367, 2009.}

\newcommand{\Toni2009}{T. Toni, D. Welch, N. Strelkowa, A. Ipsen, and M. P. H. Stumpf. Approximate Bayesian computation scheme for parameter inference and model selection in dynamical systems. \emph{Journal of the Royal Society Interface} \bold{6}, 187--202, 2009.}

\newcommand{\Toni2010}{T. Toni and M. P. H. Stumpf. Simulation-based model selection for dynamical systems in systems and population biology. \emph{Bioinformatics} \bold{26}, 104--110, 2010.}

\newcommand{\WHO2014}{WHO Ebola Response Team. Ebola virus disease in West Africa---the first 9 months of the epidemic and forward projections. \emph{New England Journal of Medicine} \bold{371}, 1481--1495, 2014.}

\newcommand{\Wood2010}{S. N. Wood Statistical inference for noisy nonlinear ecological dynamic systems. \emph{Nature} \bold{466}, 1102--1104, 2010.}

\newcommand{\Xia2011}{Y. Xia and H. Tong. Feature matching in time series modeling. \emph{Statistical Science} \bold{26}, 21--46, 2011.}

\newcommand{\Hyndman1996}{R. J. Hyndman and Y. Fan. Sample quantiles in statistical packages. \emph{American Statistician} \bold{50}, 361--365, 1996.}

\newcommand{\Harrell1982}{F. E. Harrell and C. E. Davis. A new distribution-free quantile estimator. \emph{Biometrika} \bold{69}, 635--640, 1982.}

==> pomp_5.3.tar.gz: pomp/man/macros/citations.Rd <==
% unlike in latex, new lines within \newcommand end the command (even using %)

\newcommand{\Anderson2001}{J.L. Anderson. An ensemble adjustment Kalman filter for data assimilation. \emph{Monthly Weather Review} \bold{129}, 2884--2903, 2001.}

\newcommand{\Andrieu2009}{C. Andrieu and G.O. Roberts. The pseudo-marginal approach for computation. \emph{Annals of Statistics} \bold{37}, 697--725, 2009.}

\newcommand{\Andrieu2010}{C. Andrieu, A. Doucet, and R. Holenstein. Particle Markov chain Monte Carlo methods. \emph{Journal of the Royal Statistical Society, Series B} \bold{72}, 269--342, 2010.}

\newcommand{\Anonymous1978}{Anonymous. Influenza in a boarding school. \emph{British Medical Journal} \bold{1}, 587, 1978.}

\newcommand{\Arulampalam2002}{M.S. Arulampalam, S. Maskell, N. Gordon, and T. Clapp. A tutorial on particle filters for online nonlinear, non-Gaussian Bayesian tracking. \emph{IEEE Transactions on Signal Processing} \bold{50}, 174--188, 2002.}

\newcommand{\Bhadra2016}{A. Bhadra and E.L. Ionides. Adaptive particle allocation in iterated sequential Monte Carlo via approximating meta-models. \emph{Statistics and Computing} \bold{26}, 393--407, 2016.}

\newcommand{\Bratley1988}{P. Bratley and B.L. Fox. Algorithm 659 Implementing Sobol's quasirandom sequence generator. \emph{ACM Transactions on Mathematical Software} \bold{14}, 88--100, 1988.}

\newcommand{\Breto2011}{C. Bretó and E. L. Ionides. Compound Markov counting processes and their applications to modeling infinitesimally over-dispersed systems. \emph{Stochastic Processes and their Applications} \bold{121}, 2571--2591, 2011.}

\newcommand{\Brillinger1980}{D.R. Brillinger, J. Guckenheimer, P. Guttorp, and G. Oster. Empirical modelling of population time series: The case of age and density dependent rates. In: G. Oster (ed.), \emph{Some Questions in Mathematical Biology} vol. 13, pp. 65--90, American Mathematical Society, Providence, 1980.}

\newcommand{\Ellner1998}{S.P. Ellner, B.A. Bailey, G.V. Bobashev, A.R. Gallant, B.T. Grenfell, and D.W. Nychka. Noise and nonlinearity in measles epidemics: combining mechanistic and statistical approaches to population modeling. \emph{American Naturalist} \bold{151}, 425--440, 1998.}

\newcommand{\Evensen1994}{G. Evensen. Sequential data assimilation with a nonlinear quasi-geostrophic model using Monte Carlo methods to forecast error statistics. \emph{Journal of Geophysical Research: Oceans} \bold{99}, 10143--10162, 1994.}

\newcommand{\Evensen2009}{G. Evensen. \emph{Data assimilation: the ensemble Kalman filter}. Springer-Verlag, 2009.}

\newcommand{\Gurney1980}{W.S.C. Gurney, S.P. Blythe, and R.M. Nisbet. Nicholson's blowflies revisited. \emph{Nature} \bold{287}, 17--21, 1980.}

\newcommand{\He2010}{D. He, E.L. Ionides, and A.A. King. Plug-and-play inference for disease dynamics: measles in large and small populations as a case study.  \emph{Journal of the Royal Society Interface} \bold{7}, 271--283, 2010.}

\newcommand{\Ionides2011}{E.L. Ionides. Discussion of \dQuote{Feature matching in time series modeling} by Y. Xia and H. Tong. \emph{Statistical Science} \bold{26}, 49--52, 2011.}

\newcommand{\Ionides2015}{E.L. Ionides, D. Nguyen, Y. Atchadé, S. Stoev, and A.A. King. Inference for dynamic and latent variable models via iterated, perturbed Bayes maps. \emph{Proceedings of the National Academy of Sciences} \bold{112}, 719--724, 2015.}

\newcommand{\Ionides2017}{E. L. Ionides, C. Bretó, J. Park, R. A. Smith, and A. A. King. Monte Carlo profile confidence intervals for dynamic systems. \emph{Journal of the Royal Society, Interface} \bold{14}, 20170126, 2017.}

\newcommand{\Joe2003}{S. Joe and F.Y. Kuo. Remark on algorithm 659: Implementing Sobol' quasirandom sequence generator. \emph{ACM Transactions on Mathematical Software} \bold{29}, 49--57, 2003.}

\newcommand{\Kendall1999}{B.E. Kendall, C.J. Briggs, W.W. Murdoch, P. Turchin, S.P. Ellner, E. McCauley, R.M. Nisbet, and S.N. Wood. Why do populations cycle? A synthesis of statistical and mechanistic modeling approaches. \emph{Ecology} \bold{80}, 1789--1805, 1999.}

\newcommand{\Kendall2005}{B.E. Kendall, S.P. Ellner, E. McCauley, S.N. Wood, C.J. Briggs, W.W. Murdoch, and P. Turchin. Population cycles in the pine looper moth (\emph{Bupalus piniarius}): dynamical tests of mechanistic hypotheses. \emph{Ecological Monographs} \bold{75} 259--276, 2005.}

\newcommand{\King2008}{A.A. King, E.L. Ionides, M. Pascual, and M.J. Bouma. Inapparent infections and cholera dynamics. \emph{Nature} \bold{454}, 877-880, 2008}

\newcommand{\King2015}{A.A. King, M. Domenech de Cellès, F.M.G. Magpantay, and P. Rohani. Avoidable errors in the modelling of outbreaks of emerging pathogens, with special reference to Ebola. \emph{Proceedings of the Royal Society of London, Series B} \bold{282}, 20150347, 2015.}

\newcommand{\King2016}{A. A. King, D. Nguyen, and E. L. Ionides. Statistical inference for partially observed Markov processes via the package \pkg{pomp}. \emph{Journal of Statistical Software} \bold{69}(12), 1--43, 2016.  An updated version of this paper is available on the \href{https://kingaa.github.io/pomp/docs.html}{package website}.}

\newcommand{\Kucherenko2005}{S. Kucherenko and Y. Sytsko. Application of deterministic low-discrepancy sequences in global optimization. \emph{Computational Optimization and Applications} \bold{30}, 297--318, 2005. \doi{10.1007/s10589-005-4615-1}.}

\newcommand{\Liu2001}{J. Liu and M. West. Combining Parameter and State Estimation in Simulation-Based Filtering. In A. Doucet, N. de Freitas, and N. J. Gordon, (eds.), \emph{Sequential Monte Carlo Methods in Practice}, pp. 197--224. Springer, New York, 2001.}

\newcommand{\London1973}{W. P. London and J. A. Yorke, Recurrent outbreaks of measles, chickenpox and mumps: I. Seasonal variation in contact rates. \emph{American Journal of Epidemiology} \bold{98}, 453--468, 1973.}

\newcommand{\Marin2012}{J.-M. Marin, P. Pudlo, C. P. Robert, and R. J. Ryder. Approximate Bayesian computational methods. \emph{Statistics and Computing} \bold{22}, 1167--1180, 2012.}

\newcommand{\McCleery1991}{R. McCleery and C. Perrins. Effects of predation on the numbers of Great Tits, \emph{Parus major}. In: C.M. Perrins, J.-D. Lebreton, and G.J.M. Hirons (eds.), \emph{Bird Population Studies}, pp. 129--147, Oxford. Univ. Press, 1991.}

\newcommand{\NLopt}{S.G. Johnson. The \pkg{NLopt} nonlinear-optimization package. \url{https://github.com/stevengj/nlopt/}.}

\newcommand{\Nicholson1957}{A.J. Nicholson. The self-adjustment of populations to change. \emph{Cold Spring Harbor Symposia on Quantitative Biology} \bold{22}, 153--173, 1957.}

\newcommand{\Reuman2006}{D.C. Reuman, R.A. Desharnais, R.F. Costantino, O. Ahmad, J.E. Cohen. Power spectra reveal the influence of stochasticity on nonlinear population dynamics. \emph{Proceedings of the National Academy of Sciences} \bold{103}, 18860-18865, 2006}

\newcommand{\Reuman2008}{D.C. Reuman, R.F. Costantino, R.A. Desharnais, J.E. Cohen. Color of environmental noise affects the nonlinear dynamics of cycling, stage-structured populations. \emph{Ecology Letters} \bold{11}, 820-830, 2008.}

\newcommand{\Roberts2009}{G.O. Roberts and J.S. Rosenthal. Examples of adaptive MCMC. \emph{Journal of Computational and Graphical Statistics} \bold{18}, 349--367, 2009.}

\newcommand{\Toni2009}{T. Toni, D. Welch, N. Strelkowa, A. Ipsen, and M. P. H. Stumpf. Approximate Bayesian computation scheme for parameter inference and model selection in dynamical systems. \emph{Journal of the Royal Society Interface} \bold{6}, 187--202, 2009.}

\newcommand{\Toni2010}{T. Toni and M. P. H. Stumpf. Simulation-based model selection for dynamical systems in systems and population biology. \emph{Bioinformatics} \bold{26}, 104--110, 2010.}

\newcommand{\WHO2014}{WHO Ebola Response Team. Ebola virus disease in West Africa---the first 9 months of the epidemic and forward projections. \emph{New England Journal of Medicine} \bold{371}, 1481--1495, 2014.}

\newcommand{\Wood2010}{S. N. Wood Statistical inference for noisy nonlinear ecological dynamic systems. \emph{Nature} \bold{466}, 1102--1104, 2010.}

\newcommand{\Xia2011}{Y. Xia and H. Tong. Feature matching in time series modeling. \emph{Statistical Science} \bold{26}, 21--46, 2011.}

\newcommand{\Hyndman1996}{R. J. Hyndman and Y. Fan. Sample quantiles in statistical packages. \emph{American Statistician} \bold{50}, 361--365, 1996.}

\newcommand{\Harrell1982}{F. E. Harrell and C. E. Davis. A new distribution-free quantile estimator. \emph{Biometrika} \bold{69}, 635--640, 1982.}
